Contributing
============

PYDAQ is intended to be a community project. You are more than welcome to contribute!

Bug reporting and New Features
----------------------------
If you find any bugs or have suggestions for new features,
please report them on [issue tracker](https://github.com/samirmartins/pydaq/issues) on GitHub.



Documentation
-------------

Documentation is as important as the library itself and PYDAQ documentation
can be found [here](https://samirmartins.github.io/pydaq/).
English is not my primary language, so if you find any typo or wrong phrases, do not hesitate to point me out.

Development environment
-----------------------

These are some basic steps to help us with coding:

1. Install and Setup Git on your computer.
3. [Fork PYDAQ](https://help.github.com/articles/fork-a-repo/)
4. [Clone the fork on your local machine](https://help.github.com/articles/cloning-a-repository/)
5. Install it in editable mode using
   ```console
   pip install -e /path/to/pydaq
   ```   
6. Create a new branch.
7. Make changes following the coding style of the project (or suggesting improvements).
8. Run the tests.
9. Write and/or adapt existing test if needed.
10. Add documentation if needed.
11. Commit.
12. [Push to your fork](https://help.github.com/articles/pushing-to-a-remote/)
13. [Open a pull request!](https://help.github.com/articles/creating-a-pull-request/)